use std::{fmt, ops};

use x11::xlib;

/// Various errors to be used in this wrapper
#[derive(Debug)]
pub enum XError {
    OpenDisplayError(String),
    DisplayKeycodesError,
    InvalidKeycodeError(xlib::KeyCode, ops::Range<i32>),
}

impl std::fmt::Display for XError {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(
            f,
            "{}",
            match self {
                XError::OpenDisplayError(display_name) =>
                    format!("error when opening display '{}'", display_name),
                XError::DisplayKeycodesError => String::from("error when running XDisplayKeycodes"),
                XError::InvalidKeycodeError(code, range) => format!("keycode {} outside of range {:?}", code, range), 
            }
        )
    }
}

impl std::error::Error for XError {}
